"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseCss = void 0;
const sass_1 = __importDefault(require("sass"));
const options_1 = require("./options");
const SPLIT_STR = `/* vite-plugin-sass-dts */\n`;
// eslint-disable-next-line @typescript-eslint/no-explicit-any
let loadedSassPreprocessor;
const parseCss = (file, fileName, config) => {
    // const sass = loadSassPreprocessor(config);
    const options = (0, options_1.getPreprocessorOptions)(config);
    const resolveFn = config.createResolver({
        extensions: [".scss", ".sass", ".css"],
        mainFields: ["sass", "style"],
        tryIndex: true,
        tryPrefix: "_",
        preferRelative: true,
    });
    const internalImporter = (url, importer, done) => {
        resolveFn(url, importer).then((resolved) => {
            if (resolved) {
                new Promise(function (resolve) {
                    resolve({ file: resolved });
                })
                    .then(done)
                    .catch(done);
            }
            else {
                done && done(null);
            }
        });
    };
    const finalImporter = [internalImporter];
    if (options.importer) {
        Array.isArray(options.importer)
            ? finalImporter.push(...options.importer)
            : finalImporter.push(options.importer);
    }
    const result = sass_1.default.renderSync({
        ...options,
        data: getData(file, fileName, options.additionalData),
        file: fileName,
        includePaths: options.includePaths,
        importer: finalImporter,
    });
    return result.css.toString();
};
exports.parseCss = parseCss;
const getData = (data, filename, additionalData) => {
    if (!additionalData)
        return `\n${SPLIT_STR}${data}`;
    if (typeof additionalData === "function") {
        return additionalData(`\n${SPLIT_STR}${data}`, filename);
    }
    return `${additionalData}\n${SPLIT_STR}${data}`;
};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
// const loadSassPreprocessor = (config: ResolvedConfig): any => {
//   try {
//     if (loadedSassPreprocessor) {
//       return loadedSassPreprocessor;
//     }
//     const fallbackPaths = require.resolve.paths?.("sass") || [];
//     const resolved = require.resolve("sass", {
//       paths: [config.root, ...fallbackPaths],
//     });
//     return (loadedSassPreprocessor = require(resolved));
//   } catch (e) {
//     throw new Error(
//       `Preprocessor dependency 'sass' not found. Did you install it?`
//     );
//   }
// };
